@@ -1,15 +1,8 @@
-from ckan.logic import ValidationError
-
-
 class BaseException(Exception):
     def __init__(self, error_message: str):
         self.error = error_message
 
 
-class ValidationError(ValidationError):
-    pass
-
-
 class SchemaParsingError(BaseException):
     pass
 
@@ -17,8 +10,10 @@ class SchemaParsingError(BaseException):
 class SchemaFieldError(BaseException):
     pass
 
+
 class UnknownTransmutator(BaseException):
     pass
 
+
 class TransmutatorError(BaseException):
-    pass
\ No newline at end of file
+    pass
