@@ -1,4 +1,5 @@
 from __future__ import annotations
+from re import T
 
 from typing import Any
 
@@ -200,6 +201,97 @@ class TestTransmutators:
         new_field_value = f"https://ckan.url/dataset/1"
         assert result["field_name"] == new_field_value
 
+    def test_concat_transmutator_with_field_link(self):
+        """We are able to use fields from schema as a concat item"""
+
+        data: dict[str, Any] = {
+            "identifier": "right-to-the-night-results",
+            "url": "https://ckan.url/dataset/",
+        }
+
+        tsm_schema = build_schema(
+            {
+                "url": {
+                    "validators": [
+                        [
+                            "tsm_concat",
+                            "https://ckan.url/dataset/",
+                            "$identifier",
+                        ]
+                    ],
+                },
+                "identifier": {},
+            }
+        )
+
+        result = call_action(
+            "tsm_transmute",
+            data=data,
+            schema=tsm_schema,
+            root="Dataset",
+        )
+
+        new_field_value = "https://ckan.url/dataset/right-to-the-night-results"
+        assert result["url"] == new_field_value
+
+    def test_concat_transmutator_with_field_link_nested(self):
+        """We are able to use fields from schema as a concat
+        item from within nested structure"""
+
+        data: dict[str, Any] = {
+            "title": "Package title",
+            "resources": [
+                {"title": "test res 1", "format": "xml"},
+                {"title": "test res 2", "format": "csv"},
+            ],
+        }
+
+        tsm_schema = {
+            "root": "Dataset",
+            "types": {
+                "Dataset": {
+                    "fields": {
+                        "title": {},
+                        "resources": {
+                            "type": "Resource",
+                            "multiple": True,
+                        },
+                    }
+                },
+                "Resource": {
+                    "fields": {
+                        "format": {
+                            "validators": ["tsm_string_only", "tsm_to_uppercase"],
+                        },
+                        "title": {
+                            "replace_from": "format",
+                            "validators": [
+                                "tsm_to_uppercase",
+                                [
+                                    "tsm_concat",
+                                    "$title",
+                                    " ",
+                                    "$self",
+                                ],
+                            ],
+                        },
+                    },
+                },
+            },
+        }
+
+        result = call_action(
+            "tsm_transmute",
+            data=data,
+            schema=tsm_schema,
+            root="Dataset",
+        )
+
+        for res in result["resources"]:
+            assert (
+                res["title"] == f"{result['title']} {res['format'].upper()}"
+            )
+
     def test_unique_only(self):
         """You can skip using $self if you want for some reason"""
         data: dict[str, Any] = {"field_name": [1, 2, 3, 3, 4, 5, 6, 6]}
@@ -207,9 +299,7 @@ class TestTransmutators:
         tsm_schema = build_schema(
             {
                 "field_name": {
-                    "validators": [
-                        "tsm_unique_only"
-                    ],
+                    "validators": ["tsm_unique_only"],
                 },
             }
         )
@@ -230,9 +320,7 @@ class TestTransmutators:
         tsm_schema = build_schema(
             {
                 "field_name": {
-                    "validators": [
-                        "tsm_unique_only"
-                    ],
+                    "validators": ["tsm_unique_only"],
                 },
             }
         )
@@ -251,9 +339,7 @@ class TestTransmutators:
         tsm_schema = build_schema(
             {
                 "field_name": {
-                    "validators": [
-                        "tsm_unique_only"
-                    ],
+                    "validators": ["tsm_unique_only"],
                 },
             }
         )
