@@ -15,3 +15,8 @@ class Field(RecordClass):
     field_name: str
     value: Any
     type: str
+    data: dict[str, Any]
+
+
+MODE_COMBINE = "combine"
+MODE_FIRST_FILLED = "first-filled"
